@@ -8,6 +8,7 @@ from .task import Task
 
 
 class Config(object):
+
     def __init__(self, config_paths=None, debug=False):
         self.debug = debug
         self.config = ConfigParser.SafeConfigParser()
@@ -15,11 +16,12 @@ class Config(object):
         for config_path in config_paths:
             self._read_config(config_path)
 
-        self.home = os.path.abspath(os.path.dirname(config_paths and config_paths[0] or '.'))
+        self.home = os.path.abspath(
+            os.path.dirname(config_paths and config_paths[0] or '.'))
 
     def _read_config(self, path):
         with open(path) as f:
-            self.config.readfp(f)        
+            self.config.readfp(f)
 
     def add_home_to_pythonpath(self):
         sys.path.append(self.home)
@@ -34,7 +36,9 @@ class Config(object):
         return Task(name, module)
 
     def tasks(self):
-        return [x.strip() for x in self.config.sections()]
+        return [x.strip() for x in self.config.sections() if
+                (not self.config.has_option(x, 'disabled')
+                 or not self.config.getboolean(x, 'disabled'))]
 
     def task_config(self, name):
         return dict(self.config.items(name))
@@ -52,7 +56,8 @@ class Config(object):
             serializer_module = 'json'
         module = import_string(serializer_module)
 
-        assert hasattr(module, 'loads') and hasattr(module, 'dumps'), 'Serializer should have loads and dumps methods'
+        assert hasattr(module, 'loads') and hasattr(
+            module, 'dumps'), 'Serializer should have loads and dumps methods'
 
         return module
 
@@ -66,4 +71,4 @@ def import_string(path):
     try:
         return getattr(_temp, mod_name)
     except AttributeError as e:
-        raise ImportError(e)
\ No newline at end of file
+        raise ImportError(e)
